# OData Integration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/odata-integration#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/odata-integration#prerequisites)
  * [Configuring the OData Integration](https://help.sap.com/docs/leanix/ea/odata-integration#configuring-the-odata-integration)
  * [Enabling OData Sharing for a Saved Search](https://help.sap.com/docs/leanix/ea/odata-integration#enabling-odata-sharing-for-a-saved-search)
  * [OData Endpoints](https://help.sap.com/docs/leanix/ea/odata-integration#odata-endpoints)
  * [Choosing an Endpoint for Your Use Case](https://help.sap.com/docs/leanix/ea/odata-integration#choosing-an-endpoint-for-your-use-case)
  * [Authentication](https://help.sap.com/docs/leanix/ea/odata-integration#authentication)


Export fact sheet data into business intelligence tools through OData endpoints.
